@@ -13,7 +13,7 @@
 #define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
 #define PARI_VERSION_SHIFT 8
 #define PARI_VCSVERSION ""
-#define PARI_MT_ENGINE "pthread"
+#define PARI_MT_ENGINE "single"
 
 #define PARI_DOUBLE_FORMAT -
 #define GCC_VERSION "gcc version 14.3.1 20250801 (Gentoo 14.3.1_p20250801 p4)"
@@ -48,5 +48,4 @@
 #define HAS_STRFTIME
 #define HAS_STAT
 #define HAS_MMAP
-#define ENABLE_TLS
 #endif
